@@ -13,7 +13,7 @@ package StorageDisplay::Collect;
 # ABSTRACT: modules required to collect data.
 # No dependencies (but perl itself and its basic modules)
 
-our $VERSION = '1.1.1'; # VERSION
+our $VERSION = '1.2.0'; # VERSION
 
 
 sub collectors {
@@ -198,55 +198,62 @@ package StorageDisplay::Collect::JSON;
 
 BEGIN {
     # Mark current package as loaded;
+    # else, we cannot use 'use StorageDisplay::Collect::JSON;' latter
     my $p = __PACKAGE__;
     $p =~ s,::,/,g;
     chomp(my $cwd = `pwd`);
     $INC{$p.'.pm'} = $cwd.'/'.__FILE__;#k"current file";
 }
 
+# This package contains
+# - two public subroutines
+#   - `use_pp_parser` to know if JSON:PP makes all the work alone
+#   - `decode_json` to decode a json text with the $json_parser object
+# - a public `new` class method that returns
+#   - a plain JSON::PP object (if boolean_values method exists)
+#   - a __PACKAGE__ object (if not) that inherit from JSON::PP
+# - an overrided `decode` method that
+#   - calls SUPER::decode
+#   - manually transforms JSON:::PP::Boolean into plain scalar
+# $json_parser is
+# - either a JSON::PP object (if boolean_values method exists)
+# - or a StorageDisplay::Collect::JSON that inherit of JSON::PP
+#   but override the decode method
+
 use base 'JSON::PP';
 
 my $has_boolean_values;
 
-my $json_pp_parser;
-
-sub create_json_pp_parser {
-    if (defined($json_pp_parser)) {
-	die "Internal error: create_json_pp_parser already called";
+sub new {
+    my $class = shift;
+    my $json_pp_parser;
+    if (!defined($has_boolean_values)) {
+	$json_pp_parser = JSON::PP->new;
+	$has_boolean_values = 0;
+	eval {
+	    # workaround if not supported
+	    $json_pp_parser->boolean_values(0, 1);
+	    $has_boolean_values = 1;
+	};
+    }
+    my $parser;
+    if ($has_boolean_values) {
+	$parser = JSON::PP->new(@_);
+	$parser->boolean_values(0, 1);
+    } else {
+	$parser = JSON::PP::new(__PACKAGE__, @_);
     }
-    $json_pp_parser = JSON::PP->new;
     eval {
 	# ignore if not supported
-        $json_pp_parser->allow_bignum;
+        $parser->allow_bignum;
     };
-    $has_boolean_values = 0;
-    eval {
-	# workaround if not supported
-	$json_pp_parser->boolean_values(0, 1);
-	$has_boolean_values = 1;
-    };
-    return $json_pp_parser;
-}
-
-my $json_parser;
-
-sub create_json_parser {
-    if (defined($json_parser)) {
-	die "Internal error: create_json_parser already called";
-    }
-    if (not defined($json_pp_parser)) {
-	die "Internal error: json_pp_parser not available";
-    }
-    if ($has_boolean_values) {
-	return $json_pp_parser;
-    }
-    $json_parser =  StorageDisplay::Collect::JSON->new();
+    return $parser;
 }
 
 sub decode {
     my $self = shift;
 
-    my $data = $json_pp_parser->decode(@_);
+    my $data = $self->SUPER::decode(@_);
 
     my %unrecognized;
 
@@ -280,10 +287,11 @@ sub decode {
     return $data;
 }
 
+my $json_parser;
+
 sub decode_json {
     if (not defined($json_parser)) {
-	$json_pp_parser = create_json_pp_parser();
-	$json_parser = create_json_parser();
+	$json_parser = __PACKAGE__->new();
     }
 
     $json_parser->decode(@_);
@@ -1782,9 +1790,12 @@ sub collect {
 		    my $size = <$dh2>;
 		    chomp($size);
 		    close $dh2;
-		    $v->{'blocks'}->{$info[3]}->{'file-size'}=$size;
+		    $v->{'blocks'}->{$info[3]}->{'size'}=$size;
 		}
-            }
+            } elsif ($info[0] eq 'block') {
+	    } else {
+		print STDERR "W: unknown VM device type: $info[0]\n";
+	    }
         }
         close $dh;
 	if ($v->{state}//'' eq 'running') {
@@ -1868,7 +1879,7 @@ StorageDisplay::Collect - modules required to collect data.
 
 =head1 VERSION
 
-version 1.1.1
+version 1.2.0
 
 Main class, allows one to register collectors and run them (through the collect method)
 
